{ TAMAboutDialog - version 1.0 by AM Software copyright  1997 Alexander Meeder

  This is a simple component with a few properties. It encapsulates the Windows API: ShellAbout
  which is a simple build in 'About' dialog.

  The following properties can be set to customize the dialog:
  * AppName: the name of the application
  * Caption: the caption of the dialog
  * ExtraInfo: extra information, to give a copyright notice or something like that (max.
    two lines of text)
  * Icon: this icon will be displayed on the About-dialog

  - When both AppName and Caption where empty the Application.Title will be displayed as both the
    caption and the application name. When one of them is empty the caption and application name display
    the value of the property that is not empty
  - When there is no icon assigned to this component the Application.Icon will be used in the about-box

  You can also test the dialog at runtime by right-clicking the component and choose
  'Test AM About Dialog'

  Have a question, suggestion? Mail me at: ameeder@dds.nl
}

unit AMAboutDialog;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, ShellApi, DsgnIntf;

type
  TAMAboutDialog = class(TComponent)
  private
    FAppName: TCaption;
    FCaption: TCaption;
    FExtraInfo: TCaption;
    FIcon: TIcon;

    FOnExecute: TNotifyEvent;
    FOnExecuted: TNotifyEvent;

    procedure SetIcon(value: TIcon);
  protected

  public
    function Execute: boolean;
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property AppName: TCaption read FAppName write FAppName;
    property Caption: TCaption read FCaption write FCaption;
    property ExtraInfo: TCaption read FExtraInfo write FExtraInfo;
    property Icon: TIcon read FIcon write SetIcon;
    property OnExecute: TNotifyEvent read FOnExecute write FOnExecute;
    property OnExecuted: TNotifyEvent read FOnExecuted write FOnExecuted;
  end;

  TAMAboutDialogEditor = class(TDefaultEditor)
  public
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: integer; override;
    procedure ExecuteVerb(Index: integer); override;
  end;

procedure Register;

implementation

// Begin of TAMAboutDialog-componenteditor

function TAMAboutDialogEditor.GetVerbCount: integer;
begin
  Result := 1;
end;

function TAMAboutDialogEditor.GetVerb(Index: integer): string;
begin
  Result := '&Test AM About-dialog';
end;

procedure TAMAboutDialogEditor.ExecuteVerb;
begin
  (Component as TAMAboutDialog).Execute;
end;

// Begin of TAMAboutDialog-component

function TAMAboutDialog.Execute: boolean;
var
  TempStr: TCaption;
begin
  if (Caption = '') and (AppName = '') then
     TempStr := Application.Title else
     if (Caption = '') or (AppName = '') then
       TempStr := Caption+AppName
     else
       TempStr := Caption+'#'+AppName;

  if Assigned(FOnExecute) then FOnExecute(Self);
  if Icon.Empty then
    Result := Boolean(ShellAbout((Owner as TForm).Handle, PChar(TempStr), PChar(ExtraInfo),
                      Application.Icon.Handle))
  else
    Result := Boolean(ShellAbout((Owner as TForm).Handle, PChar(TempStr), PChar(ExtraInfo),
                      FIcon.Handle));
  if Assigned(FOnExecuted) then FOnExecuted(Self);
end;

procedure TAMAboutDialog.SetIcon(value: TIcon);
begin
  FIcon.Assign(value);
end;

constructor TAMAboutDialog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FIcon := TIcon.Create;
end;

destructor TAMAboutDialog.Destroy;
begin
  FIcon.Free;
  inherited Destroy;
end;

procedure Register;
begin
  RegisterComponents('Dialogs', [TAMAboutDialog]);
  RegisterComponentEditor(TAMAboutDialog, TAMAboutDialogEditor);
end;

end.
